translate.convert.rc2po

Package translate :: Package convert :: Module rc2po |
[hide private]
[frames] | no frames]

# Module rc2po

source code

convert .rc files to Gettext PO localization files

Classes | [hide private]
| rc2po Convert a .rc file to a .po file for handling the translation.

Functions | [hide private]
convertrc(input_file, output_file, template_file, pot=False, duplicatestyle="msgctxt", charset=None, lang=None, sublang=None) reads in input_file using rc, converts using rc2po, writes to output_file | source code
main(argv=None) | source code

Imports: sys, po, rc